# -*- coding: UTF-8 -*-
"""
Module de tests unitaires pour les parsers dom
"""
import autopath

from xml.dom.minidom import parseString, parse
from era.noyau import domparsers

from era.noyau.fwobjects import Extremite, Service


EXTR_NODE = """<extremite zone='zoneA' name='extr1' libelle='libelle1' netmask='255.255.255.255'>
<ip address='192.168.230.58' />
<ip address='192.168.230.59' />
<ip address='192.168.230.60' />
</extremite>
"""

def test_service():
    s1 = Service("serv1", "TCP", [80], "serv1", "libelle_Internet")

def _init():
    self._init_services()
    self._init_extremites()
    self._init_flux()
        
    def _init_zones(self):
        zoneA = Zone('zoneA', 30, '127.0.0.1')
        zoneB = Zone('zoneB', 31, '127.0.0.1')
        zoneC = Zone('zoneC', 32, '127.0.0.1')
        
        self.zones = {'zoneA': zoneA,
                 'zoneB': zoneB,
                 'zoneC': zoneC
                      }

    def _init_services(self):
        s1 = Service("serv1", "TCP", [80], "serv1", "libelle_Internet")
        s2 = Service("serv1", "TCP", [480], "serv2", "libelle2")
        s3 = Service("Youpi", "UDP", [4513], "serv3", "libelle3")
        s4 = ServiceGroupe("Groupe1", "test de groupe de srevices",[s1,s2])
        self.services = {"serv1" : s1, "serv2" : s2, "Youpi" : s3}
        self.groups = {"Group1" : s4}

        s_store = Service("serv1", "TCP", [8080], "serv1", "test1")
        self.library_store = []
        self.library_store.append(s_store)


    def _init_extremites(self):
        e1 = Extremite(self.zones['zoneA'],"extr1", "libelle1", ["10.0.0.1"], "255.255.255.255")
        e2 = Extremite(self.zones['zoneA'],"extr2", "libelle2", ["10.0.0.2"], "255.255.255.255")
        e3 = Extremite(self.zones['zoneB'],"extr3", "libelle3", ["10.0.0.3"], "255.255.255.255")
        e4 = Extremite(self.zones['zoneC'],"extr4", "libelle4", ["10.0.0.4"], "255.255.255.255")
        self.extremites = {"extr1" : e1,"extr2" : e2,"extr3" : e3,"extr4" : e4}
        
    
        
    def test_parse_zone(self):
        doc = parseString(ZONE_NODE)
        z = domparsers.instantiate_zone_from_dom(doc.firstChild)
        self.assert_(z.name == "bastion", "Le nom de la zone n'est pas correct")
        self.assert_(z.level == 100, "Le niveau de la zone n'est pas correct")
        self.assert_(z.ip == "127.0.0.1", "L'ip de la zone n'est pas correcte")
        self.assert_(z.network == "0.0.0.0", "Le network de la zone n'est pas correct")
        self.assert_(z.netmask == "255.255.255.255", "Le netmask de la zone n'est pas correct")
        self.assert_(z.interface == "lo", "L'interface de la zone n'est pas correcte")


    def test_parse_service(self):
        doc = parseString(SERVICE_NODE)
        s = domparsers.instantiate_service_from_dom(doc.firstChild)
        self.assert_(s.name == "serv1", "Le nom du service n'est pas correct")
        self.assert_(s.protocol == "tcp", "Le protocole du service n'est pas correct")
        self.assert_(s.port_list == [8080], "La liste de ports du service n'est pas correcte")
        self.assert_(s.id == 'test1', "L'id du service n'est pas correct")
        self.assert_(s.libelle == 'ce service est un test', "le libellé du service n'est pas correct")
        

    def test_parse_extremite(self):
        doc = parseString(EXTR_NODE)
        ext = domparsers.instantiate_extremite_from_dom(doc.firstChild, self.zones)
        self.assert_(ext.name == "extr1", "Le nom de l'extremite n'est pas correct")
        self.assert_(ext.libelle == "libelle1", "Le libelle de l'extremite n'est pas correct")
        self.assert_(ext.netmask == "255.255.255.255", "Le netmask de l'extremite n'est pas correct")
        self.assert_(ext.ip_list == ['192.168.230.58','192.168.230.59','192.168.230.60'],
                     "La liste des ip n'est pas correcte")
        

    def test_parse_directive(self):
        doc = parseString(DIRECTIVE_NODE)
        d = domparsers.instantiate_directive_from_dom(doc.firstChild,
                                                      self.extremites, self.services, self.groups, {})
        self.assert_(len(d.src_list) == 2, "La longueur des sources n'est pas correcte")
        self.assert_(len(d.dest_list) == 1, "La longueur des destinations n'est pas correcte")
        self.assert_(d.action == 1, "L'action n'est pas correct")
        self.assert_(d.attrs == 2, "Les attributs ne sont pas corrects")
        self.assert_(d.service.name == 'serv1', "Le service de la directive n'est pas correct")
        

    def test_parse_nat_directive(self):
        doc = parseString(NAT_DIRECTIVE_NODE)
        d = domparsers.instantiate_directive_from_dom(doc.firstChild,
                                                      self.extremites, self.services, self.groups,{})
        
        self.assert_(d.nat_extr.name == 'extr4', "L'extrémité NAT n'est pas correcte")
        self.assert_(d.nat_port == 1234, "Le port NAT n'est pas correct")
        

