# -*- coding: UTF-8 -*-
"""Module de tests unitaires pour la gestion des directives ERA
"""

__revision__ = '$Id: unittest_directives.py,v 1.1 2004/06/15 07:23:47 eole Exp $'

import autopath

from era.backend.processors import get_processor, DNATDirectiveProcessor, \
     LOGDirectiveProcessor, MARKDirectiveProcessor, BasicDirectiveProcessor, \
     SNATDirectiveProcessor, RedirectDirectiveProcessor

import unittest
import sys


class FakeDirective(object):
    """Emule la classe directive (pour les actions)
    """
    ACTION_DENY = 1
    ACTION_ALLOW = 2
    ACTION_FORWARD = 4
    ACTION_DNAT = 8
    ACTION_MASK = 16

    def __init__(self, action):
        self.action = action


class DirectiveTC(unittest.TestCase):
    """Classe de tests unitaires pour les directives ERA
    """

    def test_processor_factory(self):
        """Teste la fabrique de processeurs
        """
        # deny
        d = FakeDirective(FakeDirective.ACTION_DENY)
        proc = get_processor(d)
        self.assert_(isinstance(proc, BasicDirectiveProcessor))
        # accept
        d = FakeDirective(FakeDirective.ACTION_ALLOW)
        proc = get_processor(d)
        self.assert_(isinstance(proc, BasicDirectiveProcessor))
        # forward
        d = FakeDirective(FakeDirective.ACTION_FORWARD)
        proc = get_processor(d)
        self.assert_(isinstance(proc, RedirectDirectiveProcessor))
        # dnat
        d = FakeDirective(FakeDirective.ACTION_DNAT)
        proc = get_processor(d)
        self.assert_(isinstance(proc, DNATDirectiveProcessor))
        # snat
        d = FakeDirective(FakeDirective.ACTION_MASK)
        proc = get_processor(d)
        self.assert_(isinstance(proc, SNATDirectiveProcessor))
        
        
def suite():
    loader = unittest.TestLoader()
    testsuite = loader.loadTestsFromModule(sys.modules[__name__])
    return testsuite    


def run():
    testsuite = suite()
    runner = unittest.TextTestRunner()
    return runner.run(testsuite)

if __name__ == '__main__':
    run()
