# -*- coding: UTF-8 -*-
"""
Test unitaires pour le module dpatterns.py
"""

import autopath
import unittest

from era.noyau import dpatterns

class SingletonImpl(dpatterns.Singleton):
    """Simple Implantation du Singleton
    """
    def __init__(self, val):
        self.val = val


class ObserverImpl(dpatterns.Observer):
    """Simple Implantation de l'observer
    Pour éviter d'avoir un raise NotImplementedError
    """

    def __init__(self):
        self.notified = False
    
    def update(self):
        self.notified = True


class DPatterns_ClassTest(unittest.TestCase):
    """
    """

    def setUp(self):
        self.sglton = SingletonImpl(10)
        self.observable = dpatterns.Observable()
        self.observer1 = ObserverImpl()
        self.observer2 = ObserverImpl()
        self.observable.register_observer(self.observer1)
        self.observable.register_observer(self.observer2)
        

    def test_singleton(self):
        """Test pour vérifier qu'on a bien une unique instance, et qu'elle
        est bien réinitialisée à chaque fois
        """
        sglton2 = SingletonImpl(15)
        self.assertEqual(id(sglton2), id(self.sglton))
        self.assertEqual(self.sglton.val, 15)


    def test_observer_notify(self):
        """Test pour vérifier que tous les observers sont bien prévenus
        """
        self.observable.notify_observers()
        self.assertEqual(self.observer1.notified, True, "Observer1 n'a pas été prévenu")
        self.assertEqual(self.observer2.notified, True, "Observer2 n'a pas été prévenu")

        
    def test_unregister_observer(self):
        """Test pour vérifier que les observers sont bien enlevés de la liste
        """
        self.observable.unregister_observer(self.observer1)
        self.assert_(self.observer1 not in self.observable.observers,
                "Observer1 est toujours dans la liste")


if __name__ == '__main__':
    unittest.main()
