# -*- coding: UTF-8 -*-
"""Module de tests unitaires pour l'écriture des règles iptables
"""

__revision__ = '$Id: unittest_writer.py,v 1.1 2004/06/15 07:23:47 eole Exp $'

import autopath

from era.backend.iptwriter import IPTWriter
from era.backend.utils import LStringIO

import unittest
import sys



class WriterTC(unittest.TestCase):
    """tests unitaires pour l'écriture des règles
    """
    def setUp(self):
        """Initialisation du writer
        """
        self.output = LStringIO()
        self.writer = IPTWriter(output = self.output)

    def test_new_chain(self):
        """Teste la méthode d'ajout d'une nouvelle chaine
        """
        self.writer.new_chain('chaineA')
        self.assertEquals(self.output.getvalue(),
                          '/sbin/iptables -t filter -N chaineA\n')
        self.writer.new_chain('chaineB', 'mangle')
        self.assertEquals(self.output[-1],
                          '/sbin/iptables -t mangle -N chaineB\n')
        
    
    def test_delete_chain(self):
        """Teste la méthode de suppression de chaine
        """
        self.writer.delete_chain('chaineA')
        self.assertEquals(self.output.getvalue(),
                          '/sbin/iptables -t filter -X chaineA\n')
        self.writer.delete_chain('chaineB', 'mangle')
        self.assertEquals(self.output[-1],
                          '/sbin/iptables -t mangle -X chaineB\n')


    def test_flush_chain(self):
        """Teste la méthode de suppression de chaine
        """
        self.writer.flush_chain('chaineA')
        self.assertEquals(self.output.getvalue(),
                          '/sbin/iptables -t filter -F chaineA\n')
        self.writer.flush_chain('chaineB', 'mangle')
        self.assertEquals(self.output[-1],
                          '/sbin/iptables -t mangle -F chaineB\n')


    def test_basic_append(self):
        """Teste la méthode d'ajout de règle *basiquement*
        Ce test n'a pour but que de tester le comportement
        de la méthode append_rule, et ne représente pas
        un cas utilisable de règle iptable
        """
        self.writer.append_rule_from_params('chaineA', 'filter', [], None)
        self.assertEquals(self.output.getvalue(),
                          '/sbin/iptables -t filter -A chaineA \n')



def suite():
    loader = unittest.TestLoader()
    testsuite = loader.loadTestsFromModule(sys.modules[__name__])
    return testsuite    

# backward compat
run = unittest.main

if __name__ == '__main__':
    unittest.main()
