# -*- coding: UTF-8 -*-
#!/usr/bin/env python

"""
Tests unitaires de zone et de zone dans la matrice de flux

"""

__revision__ = "$Id: unittest_zone.py,v 1.2 2004/02/13 13:23:15 adrien Exp $"

import autopath
import unittest

from era.noyau.erreurs import *
from era.noyau.fwobjects import *
from era.noyau.models import *
    
APP = 'editeur'
DIR = 'i18n'
import locale, gettext
# locale.setlocale (locale.LC_ALL, '')
gettext.bindtextdomain (APP, DIR)
gettext.textdomain (APP)
# installons la fonction _() dans les builtins
gettext.install (APP, DIR, unicode=1)


class TestZone(unittest.TestCase):
    def setUp(self):
        """Mise en place des objets à tester
        """
        # Une matrice de flux
        self.matrice = MatrixModel()

        # quelques objets zone, exemple : 
        # self.zone = Zone(name, level, ip, network, netmask, interface)
        self.zone1 = Zone("essai", 55, "192.168.230.22", "192.168.230.0", "255.255.255.0", "eth0")
        # créons la même zone 
        self.zone1_bis = Zone("essai", 55, "192.168.230.22", "192.168.230.0", "255.255.255.0", "eth0")
        # d'autres zones...
        self.zone2 = Zone("bastion", 100, "192.168.230.65")
        self.zone3 = Zone("zone3", 12, "192.168.230.14")

    def tearDown(self):
        """Ménage
        """
        self.matrice = None
        self.zone1 = None
        self.zone1_bis = None
        self.zone2 = None
        self.zone3 = None    

    def test_eq(self):
        """Egalité de zones
        """
        self.assertEqual(self.zone1, self.zone1_bis)


    def test_cmp(self):
        """Comparaison selon le niveau de sécurité de deux zones
        """
        self.failIf(self.zone1 > self.zone2)


    def test_ajout_matrice(self):
         """Ajout d'une zone à la matrice
         """
         self.matrice.add_zone(self.zone1)
         self.matrice.add_zone(self.zone2)

         self.assertEqual(len(self.matrice.zones), 2)
         self.assertEqual(len(self.matrice.flux), 1)
   

    def test_ajout_niveau(self):
         """Cohérence de l'ordonnancement des zones dans la matrice
         """
         self.matrice.add_zone(self.zone1)
         self.matrice.add_zone(self.zone2)
         self.matrice.add_zone(self.zone3)

         self.assertEqual(self.matrice.zones, [self.zone3, self.zone1, self.zone2])


         
class TestZoneBadInput(unittest.TestCase):
    def setUp(self):
        """Mise en place des objets à tester
        """
        # Une matrice de flux
        self.matrice = MatrixModel()

        # quelques objets zone
        # self.zone1 = Zone(name, level, ip, network, netmask, interface)
        self.zone1 = Zone("essai", 55, "192.168.230.22", "192.168.230.0", "255.255.255.0", "eth0")
        # créons la même zone 
        self.zone1_bis = Zone("essai", 55, "192.168.230.22", "192.168.230.0", "255.255.255.0", "eth0")
        # d'autres zones...
        self.zone2 = Zone("bastion", 100, "192.168.230.65")
        self.zone3 = Zone("zone3", 12, "192.168.230.14")

        # zone vide
        self.zone_vide = Zone("", 12, "192.168.230.14")
        self.zone1_tri = Zone("essai_trigramme", 55, "192.168.230.22", "192.168.230.0", "255.255.255.0", "eth0")
     

    def tearDown(self):
        """Ménage
        """
        self.matrice = None
        self.zone1 = None
        self.zone1_bis = None
        self.zone2 = None
        self.zone3 = None    

    def test_zone_vide(self):
        """Imossible d'ajouter une zone avec un nom vide
        """
        self.assertRaises(EmptyNameError,self.matrice.add_zone, self.zone_vide)


    def test_zone_existe(self):
        """Impossible d'ajouter deux zones identiques
        """
        self.matrice.add_zone(self.zone1)
        self.assertRaises(TrigrammeError,self.matrice.add_zone, self.zone1_bis)


    def test_zone_trigramme(self):
        """Les trigrammes des noms de zones sont identiques
        """
        self.matrice.add_zone(self.zone1)
        self.assertRaises(TrigrammeError,self.matrice.add_zone, self.zone1_tri)
    
if __name__ == "__main__":
    unittest.main()
